@@ -31,9 +31,12 @@
 
 #include <glib.h>
 
-#include <bluetooth/bluetooth.h>
-#include <bluetooth/l2cap.h>
-#include <gdbus/gdbus.h>
+#include "lib/bluetooth.h"
+#include "lib/l2cap.h"
+#include "lib/sdp.h"
+
+#include "gdbus/gdbus.h"
+
 #include "src/dbus-common.h"
 #include "src/log.h"
 #include "src/error.h"
@@ -42,7 +45,6 @@
 #include "src/sdpd.h"
 #include "btio/btio.h"
 
-#include "mcap_lib.h"
 #include "hdp_types.h"
 #include "hdp_util.h"
 #include "hdp.h"
@@ -81,7 +83,7 @@ struct hdp_tmp_dc_data {
 struct hdp_echo_data {
 	gboolean		echo_done;	/* Is a echo was already done */
 	gpointer		buf;		/* echo packet sent */
-	uint			tid;		/* echo timeout */
+	guint			tid;		/* echo timeout */
 };
 
 static struct hdp_channel *hdp_channel_ref(struct hdp_channel *chan)
